==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/dsl/internal/core/v1/LimitRangeOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.core.v1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DoneableLimitRange;
import io.fabric8.kubernetes.api.model.LimitRange;
import io.fabric8.kubernetes.api.model.LimitRangeList;
import io.fabric8.kubernetes.api.model.DoneableLimitRange;

import java.util.Map;
import java.util.TreeMap;


public class LimitRangeOperationsImpl extends HasMetadataOperation<LimitRange, LimitRangeList, DoneableLimitRange, Resource<LimitRange, DoneableLimitRange>> {

  public LimitRangeOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public LimitRangeOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public LimitRangeOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("")
    .withApiGroupVersion("v1")
    .withPlural("limitranges"));
    this.type = LimitRange.class;
    this.listType = LimitRangeList.class;
    this.doneableType = DoneableLimitRange.class;
  }

  public LimitRangeOperationsImpl newInstance(OperationContext context) {
    return new LimitRangeOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.6.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/core/v1/LimitRangeOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.core.v1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.LimitRange;
import io.fabric8.kubernetes.api.model.LimitRangeBuilder;
import io.fabric8.kubernetes.api.model.LimitRangeList;

import java.util.Map;
import java.util.TreeMap;


public class LimitRangeOperationsImpl extends HasMetadataOperation<LimitRange, LimitRangeList, Resource<LimitRange>> {

  public LimitRangeOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public LimitRangeOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public LimitRangeOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("")
    .withApiGroupVersion("v1")
    .withPlural("limitranges"));
    this.type = LimitRange.class;
    this.listType = LimitRangeList.class;
  }

  public LimitRangeOperationsImpl newInstance(OperationContext context) {
    return new LimitRangeOperationsImpl(context);
  }

  @Override
  public LimitRange edit(Visitor... visitors) {
    return patch(new LimitRangeBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
